@@ -20,7 +20,7 @@ sub root :Chained(/) PathPart('') CaptureArgs(0) { }
   sub register :Chained(root) PathPart('register') Args(0) {
     my ($self, $c) = @_;
     $c->redirect_to_action('home') if $c->user_exists;
-    $c->stash(person => my $model = $c->model('Schema::Person')->new_result($c->req->body_data||+{}));
+    $c->stash(person => my $model = $c->model('Schema::Person')->new_result($c->req->body_data||+{}));  # dont do this
     $model->insert if $c->req->method eq 'POST';
     return $c->redirect_to_action('login') if $model->in_storage;
   }
@@ -32,10 +32,16 @@ sub root :Chained(/) PathPart('') CaptureArgs(0) { }
 
     sub profile :Chained(auth) PathPart('profile') Args(0) {
       my ($self, $c) = @_;
-      my %params = %{$c->req->body_data||+{}};
       
-      Dwarn \%params;
+      my %params = %{$c->req->body_data||+{}};
+      %params = %{$params{person}} if exists $params{person};
 
+      Dwarn my $profile_params = $c->model('ProfileParams', a=>1);
+      Dwarn $profile_params->tags;
+      Dwarn "sdfsdfsdfsd";
+
+
+      $c->stash(states => $c->model('Schema::State'));
       $c->stash(person => my $model = $c->model('Schema::Person')
         ->find(
           { 'me.id'=>$c->user->id },
@@ -43,10 +49,17 @@ sub root :Chained(/) PathPart('') CaptureArgs(0) { }
         )
       );
 
-      if($c->req->method eq 'POST') {
-        $params{roles} = [] unless exists $params{roles}; # Handle the delete all case
-        my $add = delete $params{add};
+      $model->namespace('Example');
 
+      if($c->req->method eq 'POST') {
+        $params{roles} = [] unless exists($params{roles}) || exists($c->req->body_data->{person}) ; # Handle the delete all case
+
+        if(exists($c->req->body_data->{person})) {
+          $params{person_roles} = [] unless exists($params{person_roles});
+        }
+
+        my $add = delete $params{add};
+      Dwarn \%params;
         $model->context('profile')->update(\%params);
         $model->build_related('credit_cards') if $add->{credit_cards};
       }
